import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { setEnvironmentData } from 'worker_threads';
import { ButtonCard } from '../components';
import TextField from '../components/TextField';
import { createSpecialist } from '../services/specialist';
import { createTeacher } from '../services/teacher';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
import Modal from './Modal';
import { Specialist } from '../model/specialist';
import { Teacher } from '../model/teacher';

export interface FormComponentData {
  name: string;
  phone: string;
  email: string;
  cpf: string;
  formation?: string;
  discipline?: string;
}

const defaultProps = {
  className: 'formComponent',
  professor: false,
  specialist: false,
  // eslint-disable-next-line react/default-props-match-prop-types
  onClickSubmit: (teacher: FormComponentData) => {
    console.log(teacher);
  },
  onClickX: () => {
    console.log('x');
  },
  closeModalChangeScreen: () => {
    console.log('change screen');
  },
};

type formComponentProps = {
  className?: string;
  professor?: boolean;
  specialist?: boolean;
  // eslint-disable-next-line react/require-default-props
  onClickSubmit: (teacher: FormComponentData) => void;
  onClickX?: () => void;
  closeModalChangeScreen?: () => void;
} & typeof defaultProps;

function FormComponent(props: formComponentProps) {
  const navigate = useNavigate();
  const {
    className,
    professor,
    specialist,
    onClickSubmit,
    onClickX,
    closeModalChangeScreen,
  } = props;

  const styles = {
    container: {
      flex: 1,
      background: colors.theme.background,
      minHeight: '100vh',
      textAlign: 'center' as const,
    },
    modal: {
      position: 'absolute' as const,
      alignself: 'center',
      justifyContent: 'center',
      top: 0,
      left: 0,
      right: 0,
      bottom: 0,
    },
    buttons: {
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
    button: {
      margin: 10,
    },
    wrapper: {
      alignItems: 'center',
      textAlign: 'center' as const,
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
  };

  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalCancel, setModalCancel] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);
  const [sendData, toggleSendData] = useState(false);

  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalCancel = () => {
    setModalCancel(!modalCancel);
  };
  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };

  const [user, setUser] = useState('');
  const [name, setName] = useState('');
  const [phone, setPhone] = useState('');
  const [email, setEmail] = useState('');
  const [cpf, setCpf] = useState('');
  const [formation, setFormation] = useState('');
  const [discipline, setDiscipline] = useState('');

  return (
    <div className={className} style={{ padding: '20px' }}>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Nome Completo"
          onChange={event => setName(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Telefone"
          onChange={event => setPhone(event.target.value)}
        />
      </div>

      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="E-mail"
          onChange={event => setEmail(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="CPF"
          onChange={event => setCpf(event.target.value)}
        />
      </div>

      {specialist && (
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Especialização"
            onChange={event => setFormation(event.target.value)}
          />
        </div>
      )}
      {professor && (
        <div style={{ display: 'flex', justifyContent: 'center' }}>
          <TextField
            placeholder="Disciplina (Opcional)"
            onChange={event => setDiscipline(event.target.value)}
          />
        </div>
      )}

      <div style={styles.wrapper}>
        <div style={{ marginRight: '1.5em' }}>
          <ButtonCard
            width="8.28em"
            height="3.29em"
            text=""
            icon={fontawesome.icons.faXmark}
            sizeIcon="2.25em"
            backgroundColor={colors.theme.blue}
            iconWidth="100%"
            onClick={() => {
              if (
                cpf.length !== 11 ||
                phone.length !== 11 ||
                name.length === 0 ||
                email.length === 0 ||
                !email.includes('@') ||
                (specialist && formation.length === 0)
              ) {
                toggleModalEmpty();
              } else {
                toggleModalSuccess();
                console.log('onclick submit form');
                onClickSubmit({
                  name,
                  phone,
                  email,
                  cpf,
                  formation,
                  discipline,
                });
              }
            }}
          />
        </div>
        <ButtonCard
          width="8.28em"
          height="3.29em"
          text=""
          icon={fontawesome.icons.faCheck}
          sizeIcon="2.25em"
          backgroundColor={colors.theme.blue}
          iconWidth="100%"
          onClick={() => {
            if (
              cpf.length !== 11 ||
              phone.length !== 11 ||
              name.length === 0 ||
              email.length === 0 ||
              !email.includes('@') ||
              (specialist && formation.length === 0)
            ) {
              toggleModalEmpty();
            } else {
              toggleSendData(!sendData);
              toggleModalSuccess();
              console.log('onclick submit form 2');
              onClickSubmit({
                name,
                phone,
                email,
                cpf,
                formation,
                discipline,
              });
            }
          }}
        />
      </div>
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos corretamente."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalCancel && (
        <div style={styles.modal}>
          <Modal
            text="Usuário não foi cadastrado."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={closeModalChangeScreen}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Usuário cadastrado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
    </div>
  );
}

FormComponent.defaultProps = defaultProps;

export default FormComponent;
