import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';

import { ButtonCard, DropDown } from '../components';

import TextArea from '../components/TextArea';
import TextField from '../components/TextField';
import { Student } from '../model/student';
import { Teacher } from '../model/teacher';
import { CreateStudentPayload } from '../services/student';
import { getAllTeachers } from '../services/teacher';
import colors from '../utils/colors';
import fontawesome from '../utils/fontawesome';
import Modal from './Modal';

const defaultProps = {
  className: 'formComponent',
  studentData: {},
  onClickLinkResponsible: () => {
    console.log();
  },
};

type formComponentStudentProps = {
  className?: string;
  studentData?: Student;
  onClickSubmit: (student: CreateStudentPayload) => void;
  onClickLinkResponsible?: () => void;
} & typeof defaultProps;

function FormComponentStudent(props: formComponentStudentProps) {
  const navigate = useNavigate();
  const { className, studentData, onClickSubmit, onClickLinkResponsible } =
    props;

  const styles = {
    container: {
      flex: 1,
      background: colors.theme.background,
      minHeight: '100vh',
      textAlign: 'center' as const,
    },
    modal: {
      position: 'absolute' as const,
      alignself: 'center',
      justifyContent: 'center',
      top: 0,
      left: 0,
      right: 0,
      bottom: 0,
    },
    buttons: {
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
    button: {
      margin: 10,
    },
    wrapper: {
      alignItems: 'center',
      textAlign: 'center' as const,
      display: 'flex',
      justifyContent: 'center',
      marginTop: '5em',
    },
  };

  const [modalEmpty, setModalEmpty] = useState(false);
  const [modalSuccess, setModalSuccess] = useState(false);
  const toggleModalEmpty = () => {
    setModalEmpty(!modalEmpty);
  };
  const toggleModalSuccess = () => {
    setModalSuccess(!modalSuccess);
  };

  const [name, setName] = useState('');
  const [birth, setBirth] = useState('');
  const [condition, setCondition] = useState('');
  const [grade, setGrade] = useState('');
  const [observations, setObservations] = useState('');
  const [teacher, setTeacher] = useState<Teacher[]>([]);
  const [responsible, setResponsible] = useState([]);

  const createPayload = (): CreateStudentPayload => {
    const payloadStudent: CreateStudentPayload = {
      name,
      birth_date: birth,
      condition,
      condition_level: grade,
      teachers: teacher.map(user => user.id),
    };
    if (observations.length !== 0) {
      payloadStudent.observations = observations;
    }
    return payloadStudent;
  };

  useEffect(() => {
    setName(studentData.name);
    setBirth(studentData.birth_date);
    setCondition(studentData.condition);
    setGrade(studentData.condition_level);
    setObservations(studentData.observations ? studentData.observations : '');
    const getTeacher = async () => {
      try {
        const getTeacherResponse: Teacher[] = await getAllTeachers();
        setTeacher(getTeacherResponse);
      } catch (err) {
        console.log(err);
      }
    };
    getTeacher();
  }, [studentData]);

  let teachers: any = [];
  for (let i = 0; i < teacher.length; i++) {
    teachers = [{ value: teacher[i].id, label: teacher[i].name }];
  }

  return (
    <div className={className} style={{ padding: '20px' }}>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Nome completo do aluno"
          acceptValue
          value={name}
          onChange={event => setName(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Data de nascimento do aluno"
          acceptValue
          value={birth}
          onChange={event => setBirth(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Síndrome/Condição"
          acceptValue
          value={condition}
          onChange={event => setCondition(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <TextField
          placeholder="Grau da Síndrome"
          acceptValue
          value={grade}
          onChange={event => setGrade(event.target.value)}
        />
      </div>
      <div
        style={{
          paddingTop: '10px',
        }}
      >
        <TextArea
          placeholder="Observações"
          acceptValue
          value={observations}
          setChange={event => setObservations(event.target.value)}
        />
      </div>
      <div style={{ display: 'flex', justifyContent: 'center' }}>
        <DropDown selectText="Professores" isMulti options={teachers} />
      </div>
      <div
        style={{
          display: 'flex',
          justifyContent: 'center',
          paddingTop: '20px',
        }}
      >
        <ButtonCard
          text="VINCULAR RESPONSÁVEL"
          disableIcon
          backgroundColor={colors.theme.blue}
          onClick={onClickLinkResponsible}
        />
      </div>

      <div style={styles.wrapper}>
        <ButtonCard
          width="8.28em"
          height="3.29em"
          text=""
          icon={fontawesome.icons.faCheck}
          sizeIcon="2.25em"
          backgroundColor={colors.theme.blue}
          iconWidth="100%"
          onClick={() => {
            if (
              name.length === 0 ||
              birth.length === 0 ||
              condition.length === 0 ||
              grade.length === 0 ||
              teacher.length === 0 ||
              responsible.length !== 0
            ) {
              toggleModalEmpty();
            } else {
              toggleModalSuccess();
              onClickSubmit(createPayload());
            }
          }}
        />
      </div>
      {modalEmpty && (
        <div style={styles.modal}>
          <Modal
            text="Preencha todos os campos corretamente."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={toggleModalEmpty}
          />
        </div>
      )}
      {modalSuccess && (
        <div style={styles.modal}>
          <Modal
            text="Aluno cadastrado com sucesso."
            hasWarningSign={false}
            areYouSureModal={false}
            width="17.5em"
            height="9.375em"
            closeModal={() => navigate(-1)}
          />
        </div>
      )}
    </div>
  );
}

FormComponentStudent.defaultProps = defaultProps;

export default FormComponentStudent;
